@@ -21,11 +21,20 @@ class SqlAlchemyHelper:
             sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
         except ImportError:
             raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
-        db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=self.pool, **kwargs))
-        session = db_session()
-        yield session
-        session.commit()
-        session.close()
+        session = None
+        try:
+            db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=self.pool, **kwargs))
+            session = db_session()
+            yield session
+        except Exception:
+            if session:
+                session.rollback()
+            raise
+        else:
+            session.commit()
+        finally:
+            if session:
+                session.close()
 
 
 def alchemy_default_to_dict(params, data, repetition=False):
