@@ -7,11 +7,13 @@ import logging
 import sys
 import traceback
 
-from lesscode.db.redis.redis_helper import RedisHelper
 from tornado.options import options
 
+from lesscode.db.redis.redis_helper import RedisHelper
+from lesscode.utils.json import JSONEncoder
+
+
 # 装饰器
-from lesscode.utils.JsonUtil import JSONEncoder
 
 
 def Cache(ex=3600 * 8, cache_key=None):
