@@ -1,11 +1,13 @@
 import base64
 import binascii
 import importlib
+import warnings
 
 
 class DES:
     @staticmethod
     def encrypt(text: str, key: str, mode=1):
+        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
         try:
             Des = importlib.import_module("Cryptodome.Cipher.DES")
         except ImportError as e:
@@ -18,6 +20,7 @@ class DES:
 
     @staticmethod
     def decrypt(text: str, key: str, mode=1):
+        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
         try:
             Des = importlib.import_module("Cryptodome.Cipher.DES")
         except ImportError as e:
@@ -33,6 +36,7 @@ class DES:
         """
         :param value: 待处理的数据
         """
+        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
         while len(value) % 8 != 0:
             value += '\0'
         return str.encode(value)
